All of lore.kernel.org
 help / color / mirror / Atom feed
* [PATCH 1/5] plugins/gemalto: vendor Gemalto on LTE atom
@ 2018-10-26  5:11 Giacinto Cifelli
  2018-10-26  5:11 ` [PATCH 2/5] atmodem/netreg: change vendor cinterion to gemalto Giacinto Cifelli
                   ` (4 more replies)
  0 siblings, 5 replies; 7+ messages in thread
From: Giacinto Cifelli @ 2018-10-26  5:11 UTC (permalink / raw)
  To: ofono

[-- Attachment #1: Type: text/plain, Size: 566 bytes --]

---
 plugins/gemalto.c | 2 +-
 1 file changed, 1 insertion(+), 1 deletion(-)

diff --git a/plugins/gemalto.c b/plugins/gemalto.c
index 5d3c77a9..43d66eb5 100644
--- a/plugins/gemalto.c
+++ b/plugins/gemalto.c
@@ -610,7 +610,7 @@ static void gemalto_post_sim(struct ofono_modem *modem)
 	ofono_call_barring_create(modem, 0, "atmodem", data->app);
 
 	if (!g_strcmp0(model, GEMALTO_MODEL_ALS3_PLS8x))
-		ofono_lte_create(modem, OFONO_VENDOR_CINTERION,
+		ofono_lte_create(modem, OFONO_VENDOR_GEMALTO,
 						"atmodem", data->app);
 }
 
-- 
2.17.1


^ permalink raw reply related	[flat|nested] 7+ messages in thread

* [PATCH 2/5] atmodem/netreg: change vendor cinterion to gemalto
  2018-10-26  5:11 [PATCH 1/5] plugins/gemalto: vendor Gemalto on LTE atom Giacinto Cifelli
@ 2018-10-26  5:11 ` Giacinto Cifelli
  2018-10-26  5:11 ` [PATCH 3/5] atmodem/netreg: rename " Giacinto Cifelli
                   ` (3 subsequent siblings)
  4 siblings, 0 replies; 7+ messages in thread
From: Giacinto Cifelli @ 2018-10-26  5:11 UTC (permalink / raw)
  To: ofono

[-- Attachment #1: Type: text/plain, Size: 1126 bytes --]

---
 drivers/atmodem/network-registration.c | 4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)

diff --git a/drivers/atmodem/network-registration.c b/drivers/atmodem/network-registration.c
index 55960c03..e493984e 100644
--- a/drivers/atmodem/network-registration.c
+++ b/drivers/atmodem/network-registration.c
@@ -1559,7 +1559,7 @@ static void creg_notify(GAtResult *result, gpointer user_data)
 					option_query_tech_cb, tq, g_free) > 0)
 			return;
 		break;
-    case OFONO_VENDOR_CINTERION:
+    case OFONO_VENDOR_GEMALTO:
               if (g_at_chat_send(nd->chat, "AT^SMONI",
                                       smoni_prefix,
                                       cinterion_query_tech_cb, tq, g_free) > 0)
@@ -2031,7 +2031,7 @@ static void at_creg_set_cb(gboolean ok, GAtResult *result, gpointer user_data)
 		g_at_chat_send(nd->chat, "AT*TLTS=1", none_prefix,
 						NULL, NULL, NULL);
 		break;
-	case OFONO_VENDOR_CINTERION:
+	case OFONO_VENDOR_GEMALTO:
 		/*
 		 * We can't set rssi bounds from Cinterion responses
 		 * so set them up to specified values here
-- 
2.17.1


^ permalink raw reply related	[flat|nested] 7+ messages in thread

* [PATCH 4/5] plugins/cinterion: use Gemalto vendor in netreg
  2018-10-26  5:11 [PATCH 1/5] plugins/gemalto: vendor Gemalto on LTE atom Giacinto Cifelli
  2018-10-26  5:11 ` [PATCH 2/5] atmodem/netreg: change vendor cinterion to gemalto Giacinto Cifelli
  2018-10-26  5:11 ` [PATCH 3/5] atmodem/netreg: rename " Giacinto Cifelli
@ 2018-10-26  5:11 ` Giacinto Cifelli
  2018-10-26  5:11 ` [PATCH 5/5] atmodem/vendor.h: remove vendor Cinterion Giacinto Cifelli
  2018-10-29 20:03 ` [PATCH 1/5] plugins/gemalto: vendor Gemalto on LTE atom Denis Kenzior
  4 siblings, 0 replies; 7+ messages in thread
From: Giacinto Cifelli @ 2018-10-26  5:11 UTC (permalink / raw)
  To: ofono

[-- Attachment #1: Type: text/plain, Size: 748 bytes --]

---
 plugins/cinterion.c | 2 +-
 1 file changed, 1 insertion(+), 1 deletion(-)

diff --git a/plugins/cinterion.c b/plugins/cinterion.c
index a18b9fe8..cd5e9e81 100644
--- a/plugins/cinterion.c
+++ b/plugins/cinterion.c
@@ -209,7 +209,7 @@ static void cinterion_post_online(struct ofono_modem *modem)
 	ofono_ussd_create(modem, 0, "atmodem", chat);
 	ofono_call_forwarding_create(modem, 0, "atmodem", chat);
 	ofono_call_settings_create(modem, 0, "atmodem", chat);
-	ofono_netreg_create(modem, OFONO_VENDOR_CINTERION, "atmodem", chat);
+	ofono_netreg_create(modem, OFONO_VENDOR_GEMALTO, "atmodem", chat);
 	ofono_call_meter_create(modem, 0, "atmodem", chat);
 	ofono_call_barring_create(modem, 0, "atmodem", chat);
 
-- 
2.17.1


^ permalink raw reply related	[flat|nested] 7+ messages in thread

* [PATCH 5/5] atmodem/vendor.h: remove vendor Cinterion
  2018-10-26  5:11 [PATCH 1/5] plugins/gemalto: vendor Gemalto on LTE atom Giacinto Cifelli
                   ` (2 preceding siblings ...)
  2018-10-26  5:11 ` [PATCH 4/5] plugins/cinterion: use Gemalto vendor in netreg Giacinto Cifelli
@ 2018-10-26  5:11 ` Giacinto Cifelli
  2018-10-29 20:03 ` [PATCH 1/5] plugins/gemalto: vendor Gemalto on LTE atom Denis Kenzior
  4 siblings, 0 replies; 7+ messages in thread
From: Giacinto Cifelli @ 2018-10-26  5:11 UTC (permalink / raw)
  To: ofono

[-- Attachment #1: Type: text/plain, Size: 450 bytes --]

---
 drivers/atmodem/vendor.h | 1 -
 1 file changed, 1 deletion(-)

diff --git a/drivers/atmodem/vendor.h b/drivers/atmodem/vendor.h
index abe2d89c..cd70c283 100644
--- a/drivers/atmodem/vendor.h
+++ b/drivers/atmodem/vendor.h
@@ -47,7 +47,6 @@ enum ofono_vendor {
 	OFONO_VENDOR_QUECTEL_M95,
 	OFONO_VENDOR_UBLOX,
 	OFONO_VENDOR_UBLOX_TOBY_L2,
-	OFONO_VENDOR_CINTERION,
 	OFONO_VENDOR_XMM,
 	OFONO_VENDOR_GEMALTO,
 };
-- 
2.17.1


^ permalink raw reply related	[flat|nested] 7+ messages in thread

* [PATCH 3/5] atmodem/netreg: rename cinterion to gemalto
  2018-10-26  5:11 [PATCH 1/5] plugins/gemalto: vendor Gemalto on LTE atom Giacinto Cifelli
  2018-10-26  5:11 ` [PATCH 2/5] atmodem/netreg: change vendor cinterion to gemalto Giacinto Cifelli
@ 2018-10-26  5:11 ` Giacinto Cifelli
  2018-10-26  5:11 ` [PATCH 4/5] plugins/cinterion: use Gemalto vendor in netreg Giacinto Cifelli
                   ` (2 subsequent siblings)
  4 siblings, 0 replies; 7+ messages in thread
From: Giacinto Cifelli @ 2018-10-26  5:11 UTC (permalink / raw)
  To: ofono

[-- Attachment #1: Type: text/plain, Size: 2949 bytes --]

---
 drivers/atmodem/network-registration.c | 16 ++++++++--------
 1 file changed, 8 insertions(+), 8 deletions(-)

diff --git a/drivers/atmodem/network-registration.c b/drivers/atmodem/network-registration.c
index e493984e..2482dfc3 100644
--- a/drivers/atmodem/network-registration.c
+++ b/drivers/atmodem/network-registration.c
@@ -178,7 +178,7 @@ static int option_parse_tech(GAtResult *result)
 	return tech;
 }
 
-static int cinterion_parse_tech(GAtResult *result)
+static int gemalto_parse_tech(GAtResult *result)
 {
 	int tech = -1;
 	GAtResultIter iter;
@@ -234,13 +234,13 @@ static void at_creg_cb(gboolean ok, GAtResult *result, gpointer user_data)
 	cb(&error, status, lac, ci, tech, cbd->data);
 }
 
-static void cinterion_query_tech_cb(gboolean ok, GAtResult *result,
+static void gemalto_query_tech_cb(gboolean ok, GAtResult *result,
                                               gpointer user_data)
 {
 	struct tech_query *tq = user_data;
 	int tech;
 
-	tech = cinterion_parse_tech(result);
+	tech = gemalto_parse_tech(result);
 
 	ofono_netreg_status_notify(tq->netreg,
 			tq->status, tq->lac, tq->ci, tech);
@@ -879,7 +879,7 @@ static void telit_ciev_notify(GAtResult *result, gpointer user_data)
 	ofono_netreg_strength_notify(netreg, strength);
 }
 
-static void cinterion_ciev_notify(GAtResult *result, gpointer user_data)
+static void gemalto_ciev_notify(GAtResult *result, gpointer user_data)
 {
 	struct ofono_netreg *netreg = user_data;
 	struct netreg_data *nd = ofono_netreg_get_data(netreg);
@@ -1562,7 +1562,7 @@ static void creg_notify(GAtResult *result, gpointer user_data)
     case OFONO_VENDOR_GEMALTO:
               if (g_at_chat_send(nd->chat, "AT^SMONI",
                                       smoni_prefix,
-                                      cinterion_query_tech_cb, tq, g_free) > 0)
+                                      gemalto_query_tech_cb, tq, g_free) > 0)
                       return;
               break;
 	}
@@ -2033,10 +2033,10 @@ static void at_creg_set_cb(gboolean ok, GAtResult *result, gpointer user_data)
 		break;
 	case OFONO_VENDOR_GEMALTO:
 		/*
 		 * We can't set rssi bounds from Cinterion responses
 		 * so set them up to specified values here
 		 *
 		 * Cinterion rssi signal strength specified as:
 		 * 0      <= -112dBm
 		 * 1 - 4  signal strengh in 15 dB steps
 		 * 5      >= -51 dBm
@@ -2050,7 +2050,7 @@ static void at_creg_set_cb(gboolean ok, GAtResult *result, gpointer user_data)
 		g_at_chat_send(nd->chat, "AT^SIND=\"rssi\",1", none_prefix,
 				NULL, NULL, NULL);
 		g_at_chat_register(nd->chat, "+CIEV:",
-				cinterion_ciev_notify, FALSE, netreg, NULL);
+				gemalto_ciev_notify, FALSE, netreg, NULL);
 		break;
 	case OFONO_VENDOR_NOKIA:
 	case OFONO_VENDOR_SAMSUNG:
@@ -2033,10 +2033,10 @@ static void at_creg_set_cb(gboolean ok, GAtResult *result, gpointer user_data)
 	case OFONO_VENDOR_GEMALTO:
 		/*
-		 * We can't set rssi bounds from Cinterion responses
+		 * We can't set rssi bounds from Gemalto responses
 		 * so set them up to specified values here
 		 *
@@ -2033,10 +2033,10 @@ static void at_creg_set_cb(gboolean ok, GAtResult *result, gpointer user_data)
 		 * so set them up to specified values here
 		 *
-		 * Cinterion rssi signal strength specified as:
+		 * Gemalto rssi signal strength specified as:
 		 * 0      <= -112dBm
 		 * 1 - 4  signal strengh in 15 dB steps
-- 
2.17.1


^ permalink raw reply related	[flat|nested] 7+ messages in thread

* Re: [PATCH 1/5] plugins/gemalto: vendor Gemalto on LTE atom
  2018-10-26  5:11 [PATCH 1/5] plugins/gemalto: vendor Gemalto on LTE atom Giacinto Cifelli
                   ` (3 preceding siblings ...)
  2018-10-26  5:11 ` [PATCH 5/5] atmodem/vendor.h: remove vendor Cinterion Giacinto Cifelli
@ 2018-10-29 20:03 ` Denis Kenzior
  2018-10-30  5:09   ` Giacinto Cifelli
  4 siblings, 1 reply; 7+ messages in thread
From: Denis Kenzior @ 2018-10-29 20:03 UTC (permalink / raw)
  To: ofono

[-- Attachment #1: Type: text/plain, Size: 205 bytes --]

Hi Giacinto,

On 10/26/2018 12:11 AM, Giacinto Cifelli wrote:
> ---
>   plugins/gemalto.c | 2 +-
>   1 file changed, 1 insertion(+), 1 deletion(-)
> 

All 5 applied, thanks.

Regards,
-Denis


^ permalink raw reply	[flat|nested] 7+ messages in thread

* Re: [PATCH 1/5] plugins/gemalto: vendor Gemalto on LTE atom
  2018-10-29 20:03 ` [PATCH 1/5] plugins/gemalto: vendor Gemalto on LTE atom Denis Kenzior
@ 2018-10-30  5:09   ` Giacinto Cifelli
  0 siblings, 0 replies; 7+ messages in thread
From: Giacinto Cifelli @ 2018-10-30  5:09 UTC (permalink / raw)
  To: ofono

[-- Attachment #1: Type: text/plain, Size: 428 bytes --]

Hi Denis,

On Mon, Oct 29, 2018 at 9:03 PM Denis Kenzior <denkenz@gmail.com> wrote:
>
> Hi Giacinto,
>
> On 10/26/2018 12:11 AM, Giacinto Cifelli wrote:
> > ---
> >   plugins/gemalto.c | 2 +-
> >   1 file changed, 1 insertion(+), 1 deletion(-)
> >
>
> All 5 applied, thanks.

Thanks, and also for the additional commit
814f7fc7442d5886b71f6ca6dd2b006eda896f00

>
> Regards,
> -Denis
>

Regards,
Giacinto

^ permalink raw reply	[flat|nested] 7+ messages in thread

end of thread, other threads:[~2018-10-30  5:09 UTC | newest]

Thread overview: 7+ messages (download: mbox.gz / follow: Atom feed)
-- links below jump to the message on this page --
2018-10-26  5:11 [PATCH 1/5] plugins/gemalto: vendor Gemalto on LTE atom Giacinto Cifelli
2018-10-26  5:11 ` [PATCH 2/5] atmodem/netreg: change vendor cinterion to gemalto Giacinto Cifelli
2018-10-26  5:11 ` [PATCH 3/5] atmodem/netreg: rename " Giacinto Cifelli
2018-10-26  5:11 ` [PATCH 4/5] plugins/cinterion: use Gemalto vendor in netreg Giacinto Cifelli
2018-10-26  5:11 ` [PATCH 5/5] atmodem/vendor.h: remove vendor Cinterion Giacinto Cifelli
2018-10-29 20:03 ` [PATCH 1/5] plugins/gemalto: vendor Gemalto on LTE atom Denis Kenzior
2018-10-30  5:09   ` Giacinto Cifelli

This is an external index of several public inboxes,
see mirroring instructions on how to clone and mirror
all data and code used by this external index.